@@ -19,7 +19,7 @@
 
 /* global variables needed for the xml library */
 int N = 0;
-int MAX_TREE_SIZE = 600000; // size of the tree in maximum
+int MAX_TREE_SIZE = 2000000; // size of the tree in maximum
 int MAX_CHAR_SIZE = 60000;  // size of char arrays in maximum
 char STR[4000][60000];
 
@@ -496,9 +496,13 @@ int str_date2JD(char *str_JD, char *str_date) {
 double str2double(char *str) {
 	int i, n, m;
 	double value = 0.0, value1 = 0.0, value2 = 0.0, sgn = 1.0;
-	char tmp1[100], tmp2[100], tmp[100], str_tmp[100];
+	char tmp1[100], tmp2[100], tmp[100], str_tmp[100], str_tmp2[100];
 
 	strasign(str_tmp, str, 0, strlen(str));
+    while (str_tmp[0] == ' ') {
+        strcpy(str_tmp2,str_tmp);
+        strasign(str_tmp, str_tmp2, 1, strlen(str));
+    }
 
 	// decide the sign
 	if (str_tmp[0] == '-' || str_tmp[0] == '+') {
